Type

Enum Type 

pub enum Type {
    Void,
    MaybeSignedInt,
    Int,
    SignedInt,
    Float,
    Bool,
    String,
    Iter,
    Struct,
    Ref(RefPointee),
}
A type in the Somni language.

Variants



Void

Represents no value, used for e.g. functions that do not return a value.



MaybeSignedInt

Represents integer that may be signed or unsigned.



Int

Represents an unsigned integer.



SignedInt

Represents a signed integer.



Float

Represents a floating point number.



Bool

Represents a boolean value.



String

Represents a string value.



Iter

Represents an iterator handle. The element type is not part of the type; it is checked at runtime when a value is produced.



Struct

Represents a struct value. The struct’s identity (name and fields) is not part of the type; it is carried by the value and checked at runtime.



Ref(RefPointee)

Represents a reference. The pointee kind is static; a struct pointee’s identity is checked at runtime.