Module error

Module error 

Errors.

Structs

MarkInSource
Marks the source code with the error location and message.

Traits

ErrorWithLocation
Represents an error that has a location in the source code.