ErrorWithLocation

Trait ErrorWithLocation 

pub trait ErrorWithLocation: Display {
    // Required method
    fn location(&self) -> Location;
}
Represents an error that has a location in the source code.

Required Methods

fn location(&self) -> Location

Returns the location of the error in the source code.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ErrorWithLocation for Error

Implementors