Module value

Module value 

Types and operations.

Structs

Place
A location that a reference points to: a root variable plus a path of field names to descend into. An empty path refers to the whole variable.
Reference
A first-class reference value: the pointee type plus the place it points to.
SomniStruct
A struct value: a struct name plus its fields, keyed by field name.

Enums

TypedValue
Represents any value in the expression language.

Traits

LoadOwned
Loads an owned Rust value from a TypedValue.
LoadStore
Converts between a borrowed Rust value and a TypedValue.
ValueType
A Rust type that is used as the storage for a Somni type.