Types and operations.
Structs
- Place
- A location that a reference points to: a root variable plus a path of field names to descend into. An empty path refers to the whole variable.
- Reference
- A first-class reference value: the pointee type plus the place it points to.
- Somni
Struct - A struct value: a struct name plus its fields, keyed by field name.
Enums
- Typed
Value - Represents any value in the expression language.