Module value

Module value 

Types and operations.

Enums

TypedValue
Represents any value in the expression language.

Traits

LoadOwned
Loads an owned Rust value from a TypedValue.
LoadStore
Converts between a borrowed Rust value and a TypedValue.
ValueType
A Rust type that is used as the storage for a Somni type.